sequencetools.yield_outer_product_of_sequences
==============================================

.. autofunction:: abjad.tools.sequencetools.yield_outer_product_of_sequences.yield_outer_product_of_sequences
